.commonSpecies: Get Matrix With UniProt Abbreviations For Selected Species As Well As Simple Names
Description
This (low-level) function allows accessing matrix with UniProt abbreviations for species frequently used in research.
This information may be used to harmonize species descriptions or extract species information out of protein-names.
Usage
.commonSpecies()
Arguments
Value
This function returns a 3-column matrix with species names and UniProt-extensions
See Also
used eg in readFasta2, readProtDiscovererFile, readMaxQuantFile, readProlineFile, readFragpipeFile