| .checkSetupGroups | R Documentation |
This (low-level) function performs an additional/final check & adjustments to sample-names after readSampleMetaData()
.checkSetupGroups(
abund,
setupSd,
gr = NULL,
sampleNames = NULL,
quantMeth = NULL,
silent = FALSE,
callFrom = NULL,
debug = FALSE
)
abund |
(matrix or data.frame) abundance data, only the colnames will be used |
setupSd |
(list) describing sammple-setup, typically produced by |
gr |
(factor) optional custom information about replicate-layout, has priority over setupSd |
sampleNames |
(character) custom sample-names, has priority over abund and setuoSd |
quantMeth |
(character) 2-letter abbreviation of name of quantitation-software (eg 'MQ') |
silent |
(logical) suppress messages |
callFrom |
(character) allow easier tracking of messages produced |
debug |
(logical) display additional messages for debugging |
In particular, when no meta-data or expriental setup was found this function tries to get a min of information
This function returns an enlaged/updated list 'setupSd' (set setupSd$sampleNames, setupSd$groups)
used in readProtDiscovererFile, readMaxQuantFile, readProlineFile, readFragpipeFile
abun1 <- matrix(1:16, ncol=8, dimnames=list(NULL,paste("samp", LETTERS[8:1], sep="_")))
sdrf1 <- data.frame(source.name=paste(rep(LETTERS[1:4],each=2), 1:2, sep="_"),
assay.name=paste0("run", 1:8), comment.data.file.=paste0("MSrun", 8:1))
setU1 <- list(level=gl(4,2), meth="lowest", sampleNames=paste("samp", LETTERS[1:8], sep="_"),
sdrfDat=sdrf1, annotBySoft=NULL)
.checkSetupGroups(abun1, setU1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.