dot-getSpeciesFromEntryName: Complete/Extract Species Information Based On EntryName

.getSpeciesFromEntryNameR Documentation

Complete/Extract Species Information Based On EntryName

Description

This (low-level) function allows completing species information when standard species EntryNames are given. Eg, for the EntryName 'RHG10_HUMAN' it will be concluded that this is Homo Sapiens

Usage

.getSpeciesFromEntryName(x, returnAs = 2)

Arguments

x

(matrix or data.frame) annotation table with columns 'EntryName' and 'Species'

returnAs

(integer) refers to which column of .commonSpecies() should be returned : use 2 for full scientific names (eg Homo sapiens), use 3 for short names (eg Human)

Value

This function returns a matrix of dimensions as 'x', the column 'Species' will be now enriched/completed

See Also

.commonSpecies, used in readDiaNNFile

Examples

anno1 <- cbind(EntryName=c("RHG10_HUMAN", "abc_unknown", "HA22_MOUSE"), Species=rep(NA, 3))
.getSpeciesFromEntryName(anno1)

wrProteo documentation built on July 24, 2026, 1:06 a.m.