removeSampleInList: Remove Samples/Columns From List Of Matrixes

View source: R/removeSampleInList.R

removeSampleInListR Documentation

Remove Samples/Columns From List Of Matrixes

Description

Remove samples (ie columns) from every instance of list of matrixes, like from objects created with proteomics import-functions from this package. Note: This function assumes same order of columns in list-elements 'listElem' !

Usage

removeSampleInList(
  dat,
  remSamp,
  listElem = c("raw", "quant", "counts", "sampleSetup"),
  silent = FALSE,
  debug = FALSE,
  callFrom = NULL
)

Arguments

dat

(list) main input to be filtered

remSamp

(integer) column number to exclude

listElem

(character) names of list-elements where columns indicated with 'remSamp' should be removed

silent

(logical) suppress messages

debug

(logical) display additional messages for debugging

callFrom

(character) allows easier tracking of messages produced

Value

This function returns a matrix including imputed values or list of final and matrix with number of imputed by group (plus optional plot)

See Also

testRobustToNAimputation

Examples

set.seed(2019)
datT6 <- matrix(round(rnorm(300)+3,1), ncol=6, dimnames=list(paste("li",1:50,sep=""),
  letters[19:24]))
datL <- list(raw=datT6, quant=datT6, annot=matrix(nrow=nrow(datT6), ncol=2))
datDelta2 <- removeSampleInList(datL, remSam=2)

wrProteo documentation built on July 24, 2026, 1:06 a.m.