shortSoftwName: Get Short Names Of Proteomics Quantitation Software

View source: R/shortSoftwName.R

shortSoftwNameR Documentation

Get Short Names Of Proteomics Quantitation Software

Description

Get/convert short names of various proteomics quantitation software names for software results handeled by this package. A 2-letter abbreviation will be returned

Usage

shortSoftwName(
  x,
  tryAsLower = TRUE,
  silent = FALSE,
  debug = FALSE,
  callFrom = NULL
)

Arguments

x

(character) software (full) name

tryAsLower

(logical) include lower-caps writing to search

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allows easier tracking of messages produced

Details

So far thuis function recognizes the following software names: "DIA-NN", "ProteomeDiscoverer", "Compomics", "MaxQuant", "Proline", "TPP", "FragPipe", "MassChroQ", "OpenMS", "Ionbot" and "Sage"

Value

This function returns a vector with 2-letter abbreviation for the software

See Also

readMaxQuantFile

Examples

shortSoftwName(c("maxquant","DIANN"))

wrProteo documentation built on July 24, 2026, 1:06 a.m.