| .getSpeciesFromEntryName | R Documentation |
This (low-level) function allows completing species information when standard species EntryNames are given. Eg, for the EntryName 'RHG10_HUMAN' it will be concluded that this is Homo Sapiens
.getSpeciesFromEntryName(x, returnAs = 2)
x |
(matrix or data.frame) annotation table with columns 'EntryName' and 'Species' |
returnAs |
(integer) refers to which column of .commonSpecies() should be returned : use 2 for full scientific names (eg Homo sapiens), use 3 for short names (eg Human) |
This function returns a matrix of dimensions as 'x', the column 'Species' will be now enriched/completed
.commonSpecies, used in readDiaNNFile
anno1 <- cbind(EntryName=c("RHG10_HUMAN", "abc_unknown", "HA22_MOUSE"), Species=rep(NA, 3))
.getSpeciesFromEntryName(anno1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.