UPS1 (see https://www.sigmaaldrich.com/FR/en/product/sigma/ups1) and UPS2 are commerical products consisting of a mix of 48 human (purified) proteins.
They are frequently used as standard in spike-in experiments, available from Sigma-Aldrich (https://www.sigmaaldrich.com/GB/en).
This function allows accessing their protein accession numbers and associated names on UniProt
getUPS1acc(updated = TRUE, silent = FALSE, debug = FALSE, callFrom = NULL)This function returns data.frame with accession-numbers as stated by the supplier ($acFull),
trimmed accession-numbers, ie without version numbers ($ac),
and associated (UniProt) entry-names ($EntryName) from UniProt
as well as the species designation for the collection of 48 human UPS1 or UPS2 proteins.
This function returns a matrix including imputed values or list of final and matrix with number of imputed by group (plus optional plot)
(logical) return updated accession number (of UBB)
(logical) suppress messages
(logical) additional messages for debugging
(character) allows easier tracking of messages produced
Please note that the UniProt accession 'P62988' for 'UBIQ_HUMAN' (as originally cited by Sigma-Aldrich)
has been withdrawn and replaced in 2010 by UniProt by the accessions 'P0CG47', 'P0CG48', 'P62979', and 'P62987'.
This initial accession is available via getUPS1acc()$acOld, now getUPS1acc()$ac contains 'P0CG47'.