View source: R/shortSoftwName.R
| shortSoftwName | R Documentation |
Get/convert short names of various proteomics quantitation software names for software results handeled by this package. A 2-letter abbreviation will be returned
shortSoftwName(
x,
tryAsLower = TRUE,
silent = FALSE,
debug = FALSE,
callFrom = NULL
)
x |
(character) software (full) name |
tryAsLower |
(logical) include lower-caps writing to search |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) allows easier tracking of messages produced |
So far thuis function recognizes the following software names: "DIA-NN", "ProteomeDiscoverer", "Compomics", "MaxQuant", "Proline", "TPP", "FragPipe", "MassChroQ", "OpenMS", "Ionbot" and "Sage"
This function returns a vector with 2-letter abbreviation for the software
readMaxQuantFile
shortSoftwName(c("maxquant","DIANN"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.