Learn R Programming

wrProteo (version 2.0.0.2)

shortSoftwName: Get Short Names of Proteomics Quantitation Software

Description

Get/convert short names of various proteomics quantitation software names for software results handeled by this package. A 2-letter abbreviation will be returned

Usage

shortSoftwName(
  x,
  tryAsLower = TRUE,
  silent = FALSE,
  debug = FALSE,
  callFrom = NULL
)

Value

This function returns a vector with 2-letter abbreviation for the software

Arguments

x

(character) software (full) name

tryAsLower

(logical) include lower-caps writing to search

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allow easier tracking of messages produced

Details

So far thuis function recognizes the following software names: "DIA-NN", "ProteomeDiscoverer", "Compomics", "MaxQuant", "Proline", "TPP", "FragPipe", "MassChroQ", "OpenMS", "Ionbot" and "Sage"

See Also

readMaxQuantFile

Examples

Run this code
shortSoftwName(c("maxquant","DIANN"))

Run the code above in your browser using DataLab