shortSoftwName: Get Short Names of Proteomics Quantitation Software
Description
Get/convert short names of various proteomics quantitation software names for software results handeled by this package.
A 2-letter abbreviation will be returned
This function returns a vector with 2-letter abbreviation for the software
Arguments
x
(character) software (full) name
tryAsLower
(logical) include lower-caps writing to search
silent
(logical) suppress messages
debug
(logical) additional messages for debugging
callFrom
(character) allow easier tracking of messages produced
Details
So far thuis function recognizes the following software names:
"DIA-NN", "ProteomeDiscoverer", "Compomics", "MaxQuant", "Proline", "TPP", "FragPipe", "MassChroQ", "OpenMS", "Ionbot" and "Sage"