- dat
(matrix or data.frame) main data (may contain NA); if dat is list containing $quant and $annot as matrix, the element $quant will be used
- gr
(character or factor) replicate association; if dat contains a list-element $sampleSetup$groups or $sampleSetup$lev this may be used in case gr=NULL
- annot
(matrix or data.frame) annotation (lines must match lines of data !), if annot is NULL and argument dat is a list containing both $quant and $annot, the element $annot will be used
- retnNA
(logical) retain and report number of NA
- avSd
(numerical,length=2) population characteristics (mean and sd) for >1 NA-neighbours (per line)
- avSdH
depreciated, please use avSd inestad; (numerical,length=2) population characteristics 'high' (mean and sd) for >1 NA-neighbours (per line)
- plotHist
(logical) additional histogram of original, imputed and resultant distribution (made using matrixNAneighbourImpute )
- xLab
(character) custom x-axis label
- tit
(character) custom title
- imputMethod
(character) choose the imputation method (may be 'mode2'(default), 'mode1', 'datQuant', 'modeAdopt', 'informed' or 'none', for details see matrixNAneighbourImpute )
- seedNo
(integer) seed-value for normal random values
- multCorMeth
(character) define which method(s) for correction of multipl testing should be run (for choice : 'BH','lfdr','BY','tValTab', choosing several is possible)
- nLoop
(integer) number of runs of independent NA-imputation
- lfdrInclude
(logical) depreciated, please used multCorMeth instead (include lfdr estimations, may cause warning message(s) concerning convergence if few too lines/proteins in dataset tested).
- ROTSn
(integer) depreciated, please used multCorMeth instead (number of repeats by ROTS, if NULL ROTS will not be called)
- silent
(logical) suppress messages
- debug
(logical) additional messages for debugging
- callFrom
(character) This function allows easier tracking of messages produced